/* IOPSYS Software Solutions AB
 * Implementation for speed dialing call numbers list
 */

#ifndef SPEEDDIAL_H
#define SPEEDDIAL_H

#include <stdint.h>

#define SPEEDDIAL_MAX_ENTRIES           200
#define SPEEDDIAL_MIN_CALLNUMBER_SIZE   3
#define SPEEDDIAL_MAX_CALLNUMBER_SIZE   24
#define SPEEDDIAL_MAGIC_VALUE           0xA5A5A501

// Macro to check if the number is valid to add to speed dialing list
#define SPEEDDIAL_IS_VALID_NUMBER(num)          ((num) != NULL && (num)[0] != '*' && (num)[0] != '#')
// Macro to check if the number is feature code to erase speed dialing call list
#define SPEEDDIAL_IS_ERASE_FEATURE_CODE(num)    ((num) != NULL && strcmp((num), "**#93#") == 0)

typedef struct {
    char call_number[SPEEDDIAL_MAX_CALLNUMBER_SIZE + 1];
    uint8_t is_valid;
} __attribute__((packed)) SpeedDialCallNumber;

typedef struct {
    uint32_t  magic;
    SpeedDialCallNumber entries[SPEEDDIAL_MAX_ENTRIES];
    uint8_t total_entries;
} __attribute__((packed)) SpeedDialCallList;

extern SpeedDialCallList speedDialCallList;

int speeddial_read_from_file(SpeedDialCallList *storage);
int speeddial_write_to_file(SpeedDialCallList *storage);
int speeddial_entry_exists(SpeedDialCallList *storage, const char *call_number);
int speeddial_add_entry(SpeedDialCallList *storage, const char *call_number);
int speeddial_delete_entry(SpeedDialCallList *storage, const char *call_number);
int speeddial_erase(SpeedDialCallList *storage);
int speeddial_dump_list(SpeedDialCallList *storage);

#endif /* SPEEDDIAL_H */